package com.hw.dms.service;

import java.util.List;
import com.hw.dms.domain.DmsMaintInstanceActivity;

/**
 * 保养工单实例节点Service接口
 *
 * @author Open Platform
 * @date 2024-02-29
 */
public interface IDmsMaintInstanceActivityService
{
    /**
     * 查询保养工单实例节点
     *
     * @param instanceActivityId 保养工单实例节点主键
     * @return 保养工单实例节点
     */
    public DmsMaintInstanceActivity selectDmsMaintInstanceActivityByInstanceActivityId(Long instanceActivityId);

    /**
     * 查询保养工单实例节点列表
     *
     * @param dmsMaintInstanceActivity 保养工单实例节点
     * @return 保养工单实例节点集合
     */
    public List<DmsMaintInstanceActivity> selectDmsMaintInstanceActivityList(DmsMaintInstanceActivity dmsMaintInstanceActivity);

    /**
     * 新增保养工单实例节点
     *
     * @param dmsMaintInstanceActivity 保养工单实例节点
     * @return 结果
     */
    public int insertDmsMaintInstanceActivity(DmsMaintInstanceActivity dmsMaintInstanceActivity);

    /**
     * 修改保养工单实例节点
     *
     * @param dmsMaintInstanceActivity 保养工单实例节点
     * @return 结果
     */
    public int updateDmsMaintInstanceActivity(DmsMaintInstanceActivity dmsMaintInstanceActivity);

    /**
     * 批量删除保养工单实例节点
     *
     * @param instanceActivityIds 需要删除的保养工单实例节点主键集合
     * @return 结果
     */
    public int deleteDmsMaintInstanceActivityByInstanceActivityIds(Long[] instanceActivityIds);

    /**
     * 删除保养工单实例节点信息
     *
     * @param instanceActivityId 保养工单实例节点主键
     * @return 结果
     */
    public int deleteDmsMaintInstanceActivityByInstanceActivityId(Long instanceActivityId);

    boolean selectUserIdByDmsMaintInstanceActivityId(Long maintInstanceId,Long userId);


}
